<?php
/**
 * TorrentPier – Bull-powered BitTorrent tracker engine
 *
 * @copyright Copyright (c) 2005-2023 TorrentPier (https://torrentpier.site)
 * @link      https://github.com/TorrentPeer/TorrentPier for the canonical source repository
 * @license   https://github.com/TorrentPeer/TorrentPier/blob/main/LICENSE MIT License
 */

if (!defined('IN_AJAX')) {
  die(basename(__FILE__));
}

global $userdata, $lang, $bb_cfg;

$mode = (string)$this->request['mode'];

switch ($mode) {

  case 'check_for_updates':

    if (($content = @file_get_contents(UPDATER_URL)) !== false) {
      $results = json_decode(utf8_encode($content), true);
      $results = next($results['package']['versions']);

      $version_code = (int)trim(str_replace(['.', 'v', ','], '', strstr($bb_cfg['tp_version'], '-', true)));
      $version_code_actual = (int)trim(str_replace(['.', 'v', ','], '', $results['version']));

      if ($version_code < $version_code_actual) {
        $this->response['updater_status'] = sprintf($lang['VERSION_NEED_UPDATE'], '<a href="' . $results['dist']['url'] . '">' . $results['version'] . '</a>');
      } else if ($version_code == $version_code_actual) {
        $this->response['updater_status'] = $lang['VERSION_ACTUAL'];
      } else if ($version_code > $version_code_actual) {
        $this->response['updater_status'] = $lang['VERSION_DEV'];
      }
    } else {
      $this->response['updater_status'] = $lang['VERSION_ERROR'];
    }

    break;

  case 'clear_cache':

    clean_cache();

    $this->response['cache_html'] = '<span class="seed bold">' . $lang['ALL_CACHE_CLEARED'] . '</span>';

    break;

  case 'clear_datastore':

    clean_datastore();

    $this->response['datastore_html'] = '<span class="seed bold">' . $lang['DATASTORE_CLEARED'] . '</span>';

    break;

  case 'clear_template_cache':

    clean_tpl_cache();

    $this->response['template_cache_html'] = '<span class="seed bold">' . $lang['ALL_TEMPLATE_CLEARED'] . '</span>';

    break;

  case 'indexer':

    exec("indexer --config {$bb_cfg['sphinx']['path']} --all --rotate", $result);

    if (!is_file($bb_cfg['sphinx']['path'] . ".log")) {
      file_put_contents($bb_cfg['sphinx']['path'] . ".log", "##############################" . date("H:i:s", TIMENOW) . "##############################\r\n\r\n\r\n\r\n", FILE_APPEND);
    }

    file_put_contents($bb_cfg['sphinx']['path'] . ".log", "##############################" . date("H:i:s", TIMENOW) . "##############################\r\n", FILE_APPEND);

    foreach ($result as $row) {
      file_put_contents($bb_cfg['sphinx']['path'] . ".log", $row . "\r\n", FILE_APPEND);
    }

    file_put_contents($bb_cfg['sphinx']['path'] . ".log", "\r\n", FILE_APPEND);
    file_put_contents($bb_cfg['sphinx']['path'] . ".log", "\r\n", FILE_APPEND);

    $this->response['indexer_html'] = '<span class="seed bold">' . $lang['INDEXER'] . '</span>';

    break;

  case 'update_user_level':

    \TorrentPier\Legacy\Group::update_user_level('all');

    $this->response['update_user_level_html'] = '<span class="seed bold">' . $lang['USER_LEVELS_UPDATED'] . '</span>';

    break;

  case 'sync_topics':

    \TorrentPier\Legacy\Admin\Common::sync('topic', 'all');
    \TorrentPier\Legacy\Admin\Common::sync_all_forums();

    $this->response['sync_topics_html'] = '<span class="seed bold">' . $lang['TOPICS_DATA_SYNCHRONIZED'] . '</span>';

    break;

  case 'sync_user_posts':

    \TorrentPier\Legacy\Admin\Common::sync('user_posts', 'all');

    $this->response['sync_user_posts_html'] = '<span class="seed bold">' . $lang['USER_POSTS_COUNT_SYNCHRONIZED'] . '</span>';

    break;

  case 'unlock_cron':

    \TorrentPier\Helpers\CronHelper::enableBoard();

    $this->response['unlock_cron_html'] = '<span class="seed bold">' . $lang['ADMIN_UNLOCKED'] . '</span>';

    break;

  case 'admin_note':

    $note = (string)$this->request['note'];

    bb_update_config(['admin_note' => $note]);

    $this->response['note_saved'] = $lang['SAVED'];

    break;

  default:

    $this->ajax_die("Invalid mode: $mode");
}

$this->response['mode'] = $mode;
